let miucms = require('../../utils/miucms')
const wxParse = require('../../wxParse/wxParse')
const app = getApp()
Component({
    properties: {
        data: {
            type: Array,
            data: [],
        },
        interface: {
            type: String,
                data: "",
        },
        init: {
            type: Boolean,
            data: false,
            observer(res) {
                if (!res) return
                let announcementPopupData = app.globalData['announcementPopupData']
                if (announcementPopupData && announcementPopupData.length > 0) {
                    this.setData({
                        announcementPopupData
                    })
                    this.extractingTargetData()
                } else if (announcementPopupData == undefined) {
                    this.getNotice()
                } else {
                    // console.log("已经请求接口并且没有数据");
                }
            }
        }
    },
    data: {
        announcementPopupWindow: false, // 公告弹窗的状态 默认不显示
        announcementPopupData: [], // 所有公告的数据
        swiperHeight: 0, // 当前 swiper 的高度
        current: 0, // 当前 swiper 下标
        targetData: [], // 目标数据
        floatingWindowState: false, // 左下角的浮动浮窗状态
    },
    methods: {
        change(e) {
            // 用户切换轮播图时间
            let current = e.detail.current
            this.setData({
                current
            })
            this.getHieght(current)
        },

        // 计算单个公告的高度，因为公告长度不一
        getHieght(current) {
            if (this.data.targetData.length <= 1) return
            let that = this
            let query = wx.createSelectorQuery()
            query.select(`.container >>> .content${current}`).boundingClientRect()
            query.exec((res) => {
                let height = res[0].height
                that.setData({
                    swiperHeight: height + 15
                })
            })
            that.statistics()
        },

        // 点击立即前往
        immediatelyTo(e) {
            let url = e.currentTarget.dataset.url
            // 跳转h5
            if (url.indexOf('http') != -1) {
                wx.navigateTo({
                    url: `/pages/webViewwebweb/index?url=${url}`,
                    success: res => {
                        this.setData({
                            announcementPopupWindow: !this.data.announcementPopupWindow
                        })
                    }
                })
                return
            }

            // 跳转本小程序页面,随便做一个 / 判断
            wx.navigateTo({
                url: url[0] == '/' ? url : "/" + url,
                success: res => {
                    this.setData({
                        announcementPopupWindow: !this.data.announcementPopupWindow
                    })
                }
            })
        },

        // 获取公告数据
        getNotice() {
            let that = this
            miucms.request(`${app.globalData.baseURL}/tenement/notice`).then(res => {
                if (res.code == 200) {
                    this.setData({
                        announcementPopupData: res.data
                    }, () => {
                        if (res.data && res.data.length == 0) return
                        res.data.forEach((element, index) => {
                            let message = res.data[index].message
                            if (message.indexOf('<') == -1) return
                            // 如果 内容一个 英文 < 就认定为html，解析 html ，iswxParse 代表 被 wxParse 解析过
                            wxParse.wxParse(`announcementPopupData[${index}].article`, 'html', message, that, 5, true)
                            that.data.announcementPopupData[index]['iswxParse'] = true
                        });
                        that.setData({
                            announcementPopupData: that.data.announcementPopupData
                        })
                        // 计算目标数据
                        this.extractingTargetData()
                    })
                    app.globalData['announcementPopupData'] = res.data
                } else {
                    wx.showModal({
                        title: '提示',
                        content: res.message
                    })
                }
            })
        },

        // 切换公告状态
        bindFloatingWindow() {
            this.setData({
                announcementPopupWindow: !this.data.announcementPopupWindow
            })
            if (this.data.announcementPopupWindow) {
                this.getHieght(this.data.current)
            }
        },

        // 提取目标数据
        extractingTargetData() {
            let targetData = []
            // 获取之前自动弹窗的 id 
            let alreadyAnnouncementPopupWindowList = app.globalData['alreadyAnnouncementPopupWindowList'] || []
            this.data.announcementPopupData.forEach(element => {
                // 将本页面的数据添加到目标数组
                if (element.launchinterface.indexOf(this.data.interface) != -1) targetData.push(element)

                // 判断是否需要显示左浮窗
                if (element.launchinterface.indexOf(this.data.interface) != -1 && element.floatingwindow == 1) {
                    this.setData({
                        floatingWindowState: true
                    })
                }

                // 判断是本页面数据及自动弹窗
                if (element.launchinterface.indexOf(this.data.interface) != -1 && element.isopenwindow == 1 && alreadyAnnouncementPopupWindowList.indexOf(element.uniqid) == -1) {
                    alreadyAnnouncementPopupWindowList.push(element.uniqid)
                    this.setData({
                        announcementPopupWindow: true,
                    })
                    app.globalData['alreadyAnnouncementPopupWindowList'] = alreadyAnnouncementPopupWindowList // 已经自动弹窗 状态
                }
            });
            this.setData({
                targetData
            })
            // 下面是自动弹窗后 需要计算高度 和 统计数据
            if (this.data.announcementPopupWindow) {
                this.getHieght(this.data.current)
            }
            // 当 目标数据只有一条时 需要发统计数据
            if (this.data.announcementPopupWindow && targetData.length == 1) {
                this.statistics()
            }
        },

        // 统计浏览量
        statistics() {
            miucms.request(`${app.globalData.baseURL}/tenement/notice/openstat`, {
                uniqid: this.data.targetData[this.data.current].uniqid
            }).then(res => {})
        },
    }
})